<?php
/**
 * Moony - the tiny web application framework
 *
 * @package   Moony
 * @author    YAMAOKA Hiroyuki <yamaoka@catwalker.jp>
 * @link      http://moony.sourceforge.jp/
 * @copyright 2005-2006 YAMAOKA Hiroyuki
 * @license   http://opensource.org/licenses/bsd-license.php The BSD License
 */

/**
 * 共有のオブジェクトを格納するレジストリクラスです。
 *
 * @package Moony
 * @author YAMAOKA Hiroyuki <yamaoka@catwalker.jp>
 * @access public
 */
class Moony_Registry
{
    /**
     * 格納されているオブジェクトの連想配列
     * @var array
     */
    var $_entries = array();

    /**
     * オブジェクトを格納します。
     *
     * @access public
     * @static
     * @param string $name 格納するオブジェクトの名称
     * @param object $object 格納するオブジェクト
     */
    function set($name, &$object)
    {
        $registry =& Moony_Registry::_getInstance();
        $registry->_entries[$name] = &$object;
    }

    /**
     * 格納されているオブジェクトを取得します。
     * 格納されていない場合、nullが返されます。
     *
     * @access public
     * @param string $name 格納されているオブジェクトの名称
     + @return object 格納されているオブジェクト
     */
    function &get($name)
    {
        $object = null;
        $registry =& Moony_Registry::_getInstance();
        if (array_key_exists($name, $registry->_entries)) {
            $object =& $registry->_entries[$name];
        }
        return $object;
    }

    /**
     * このクラスのSingletonインスタンスを取得します。
     *
     * @access protected
     * @static
     * @return object このクラスのSingletonインスタンス
     */
    function &_getInstance()
    {
        static $instance;
        if (is_null($instance)) {
            $instance = new Moony_Registry();
        }
        return $instance;
    }
}
?>
